==> falak-0.1.5.tgz: package/framework/compiler/parser/parser.js <==
const Tag = require('./tag');
const path = require('path');
const { JSDOM } = require("flk-parser");
const minify = require("babel-minify");
const HtmlCompiler = require('./html-compiler');
const { fs } = require('./../../bootstrap/modules');

class Parser {
    constructor(html, filePath, env = Parser.DEVELOPMENT_MODE) {
        html = this.handleCustomSelfClosedTagsFirst(html);
        const dom = new JSDOM(html);

        this.debugger = true;

        this.env = env;

        this.filePath = filePath;

        this.viewName = Parser.getViewName(filePath);

        this.filename = path.basename(filePath).rtrim('.html');

        global.document = dom.window.document;

        this.html = html;

        this.htmlCompiler = new HtmlCompiler(this.html, this.viewName);

        this.htmlCompiler.parser = this;
    }

    /**
     * Handle custom self closed tags before parsing the html
     * 
     * @param   string html
     * @returns string
     */
    handleCustomSelfClosedTagsFirst(html) {
        return html.replace(/<([^\/>]+)\/>/g, (matchedTag, tagContent) => {
            let [tagName] = tagContent.split(' ');

            if (Tag.selfClosedTags.includes(tagName.toLowerCase())) return matchedTag;

            return `<${tagContent.rtrim()}></${tagName}>`;
        });
    }

    parse() {
        return new Promise(resolve => {
            if (this.debugger) {
                echo(cli.blueBright(`Recompiling ${this.viewName}`));
            }

            this.htmlCompiler.parse();

            this.parsed = this.htmlCompiler.getCompiledCode(this.env);

            let fileContent = `${this.parsed}`.trim();

            if (this.env == Parser.PRODUCTION_MODE) {
                fileContent = minify(fileContent).code;
            }

            let parsedFilePath = `${ROOT}/public/static/${APP_NAME}/smart-views/${this.viewName.replace(/\//g, '-')}.js`;

            fs.put(parsedFilePath, fileContent);
            if (this.debugger) {
                echo(`${this.viewName} has been compiled successfully`);
            }

            resolve(parsedFilePath);
        });
    }

    /**
     * Disable/Enable console messaging
     * 
     * @param   bool debug
     * @returns void
     */
    debug(debug) {
        this.debugger = debug;
    }


    /**
     * Prepare view name
     * 
     * @param string filePath 
     */
    static getViewName(filePath) {
        filePath = filePath.replace(/\\/g, '/').replace(/\.\/|\.\.\/|compiler\/components/g, '').replace(/\/\//g, '/').ltrim(SRC_DIR).trim('/');

        if (filePath.includes(FRAMEWORK_NAME)) {
            filePath = filePath.replace(new RegExp(FRAMEWORK_NAME), '');
        } else {
            filePath = filePath.removeFirst(`${APP_NAME}/components`);

            // prepend the app name at the beginning
            filePath = APP_NAME + filePath;
        }

        filePath = filePath.trim('/');

        if (filePath.endsWith('.component.html')) {
            filePath = filePath.removeLast('.component.html');
        } else if (filePath.endsWith('.html')) {
            filePath = filePath.removeLast('.html');
        }

        return filePath;
    }
}

Parser.DEVELOPMENT_MODE = 'dev';
Parser.PRODUCTION_MODE = 'prod';

module.exports = Parser;

==> falak-0.1.24.tgz: package/framework/compiler/parser/parser.js <==
const Tag = require('./tag');
const path = require('path');
const { JSDOM } = require("flk-parser");
// const minify = require("babel-minify");
const HtmlCompiler = require('./html-compiler');
const { fs } = require('./../../bootstrap/modules');

class Parser {
    constructor(html, filePath, env = Parser.DEVELOPMENT_MODE) {
        html = this.handleCustomSelfClosedTagsFirst(html);
        const dom = new JSDOM(html);

        this.debugger = true;

        this.env = env;

        this.filePath = filePath;

        this.viewName = Parser.getViewName(filePath);

        this.filename = path.basename(filePath).rtrim('.html');

        global.document = dom.window.document;

        this.html = html;

        this.htmlCompiler = new HtmlCompiler(this.html, this.viewName);

        this.htmlCompiler.parser = this;
    }

    /**
     * Handle custom self closed tags before parsing the html
     * 
     * @param   string html
     * @returns string
     */
    handleCustomSelfClosedTagsFirst(html) {
        return html.replace(/<([^\/>]+)\/>/g, (matchedTag, tagContent) => {
            let [tagName] = tagContent.split(' ');

            if (Tag.selfClosedTags.includes(tagName.toLowerCase())) return matchedTag;

            return `<${tagContent.rtrim()}></${tagName}>`;
        });
    }

    parse() {
        return new Promise(resolve => {
            if (this.debugger) {
                echo(cli.blueBright(`Recompiling ${this.viewName}`));
            }

            this.htmlCompiler.parse();

            this.parsed = this.htmlCompiler.getCompiledCode(this.env);

            let fileContent = `${this.parsed}`.trim();

            // if (this.env == Parser.PRODUCTION_MODE) {
            //     fileContent = minify(fileContent).code;
            // }

            let parsedFilePath = `${ROOT}/public/${APP_NAME}/smart-views/${this.viewName.replace(/\//g, '-')}.js`;

            fs.put(parsedFilePath, fileContent);
            if (this.debugger) {
                echo(`${this.viewName} has been compiled successfully`);
            }

            resolve(parsedFilePath);
        });
    }

    /**
     * Disable/Enable console messaging
     * 
     * @param   bool debug
     * @returns void
     */
    debug(debug) {
        this.debugger = debug;
    }


    /**
     * Prepare view name
     * 
     * @param string filePath 
     */
    static getViewName(filePath) {
        filePath = filePath.replace(/\\/g, '/').replace(/\.\/|\.\.\/|compiler\/components/g, '').replace(/\/\//g, '/').ltrim(SRC_DIR).trim('/');

        if (filePath.includes(FRAMEWORK_NAME)) {
            filePath = filePath.replace(new RegExp(FRAMEWORK_NAME), '');
        } else {
            filePath = filePath.removeFirst(`${APP_NAME}/components`);

            // prepend the app name at the beginning
            filePath = APP_NAME + filePath;
        }

        filePath = filePath.trim('/');

        if (filePath.endsWith('.component.html')) {
            filePath = filePath.removeLast('.component.html');
        } else if (filePath.endsWith('.html')) {
            filePath = filePath.removeLast('.html');
        }

        return filePath;
    }
}

Parser.DEVELOPMENT_MODE = 'dev';
Parser.PRODUCTION_MODE = 'prod';

module.exports = Parser;
